# setup.py
import setuptools

setuptools.setup(
    name='app_66613',  # Имя пакета
    version='0.0.1',  # Версия пакета
    author='PowerMa1ner',
    author_email='romankomarov154@gmail.com',
    description='app_66613',
    packages=setuptools.find_packages(),
)